const { PythonShell } = require('python-shell')
const { Lock } = require('semaphore-async-await')

const PYTHON_PATH = `${__dirname}/python_workers/venv/Scripts/python.exe`

const pythonShellDefaultOptions = {
  pythonPath: PYTHON_PATH,
  mode: 'json'
}

function PythonWorker (workerScript, shellOptions) {
  this.toPythonLock = new Lock()
  this.fromPythonLock = new Lock()
  this.data = []
  this.workerScript = workerScript
  this.pythonShellOptions = { ...pythonShellDefaultOptions, shellOptions }
  this.pythonShell = new PythonShell(this.workerScript, this.pythonShellOptions)
  this.pythonShell.on('message', message => {
    this.data.push(message)
    this.fromPythonLock.release()
  })
  this.pythonShell.on('error', error => {
    this.error = error
  })
  this.send = async (command) => {
    await this.toPythonLock.acquire()
    await this.fromPythonLock.acquire()
    this.pythonShell.send(command)
    await this.fromPythonLock.acquire()
    const res = this.data.pop()
    this.fromPythonLock.release()
    this.toPythonLock.release()
    return res
  }
}

module.exports = PythonWorker
