import { Query, Mutation } from 'react-apollo';
import gql from 'graphql-tag'
import { QUERY_PROJECTS } from './ProjectList'

const ADD_CHARACTERIZATION = gql`
  mutation ADD_CHARACTERIZATION($name: String!, $projectVersion: ID!, $measurementRuns: [MeasurementRun!]) {
    createCharacterization(data: {name: $name, projectVersion: $projectVersion, measurementRuns: $measurementRuns}) {
      id
      name
      projectVersion {
        id
        name
      }
      measurementRuns {
        id
        name
      }
    }
  }
`

const QUERY_PROJECT_VERSIONS = gql`
  query QUERY_PROJECT_VERSIONS($projectId: ID!) {
    projectVersions(where: {project: {id: $projectId}}) {
      id
      name
    }
  }
`

class CharacterziationForm extends React.Component {
  state = {
    name: '',
    project: null,
    projectVersion: null,
    measurementRuns: null
  }

  toState = event => {
    this.setState({ [event.target.name]: event.target.value })
  }

  render() {
    return (
      <Mutation mutation={ADD_CHARACTERIZATION} variables={this.state}>
        {(addCharacterization, { data, error, loading }) => (
          <form onSubmit={event => {
            event.preventDefault()
            console.log(this.state)
            addCharacterization()
          }}>
            <fieldset>
              <label htmlFor="name">Characterization name</label>
              <input type="text" name="name" id="name"
                placeholder="Characterization name"
                value={this.state.name}
                onChange={this.toState}
              />
              <Query query={QUERY_PROJECTS}>
                {({ data, error, loading }) => {
                  if (error) return (<p>Error loading project: ${error.message}</p>)
                  if (loading) return (<p>Loading data...</p>)
                  if (!data) return (<p>No project found.</p>)

                  const { projects } = data
                  return (
                    <>
                      <label htmlFor="project">Project</label>
                      <select name="project" id="project" onChange={this.toState}>
                        <option value={null}>---</option>
                        {data.projects.map(project => <option key={project.id} value={project.id}>{project.name}</option>)}
                      </select>
                      <Query query={QUERY_PROJECT_VERSIONS} variables={{ projectId: this.state.project }}>
                        {({ data, error, loading }) => {
                          if (error) return (<p>Error loading project version: ${error.message}</p>)
                          if (loading) return (<p>Loading data...</p>)
                          if (!data) return (<p>No project version found.</p>)

                          const { projectVersions } = data
                          return (
                            <>
                              <label htmlFor="projectVersion"></label>
                              <select name="projectVersion" id="projectVersion" onChange={this.toState}>
                                <option value={null}>---</option>
                                {data.projectVersions.map(projectVersion =>
                                  <option key={projectVersion.id} value={projectVersion.id}>{projectVersion.name}</option>
                                )}
                              </select>
                            </>
                          )
                        }}
                      </Query>
                    </>
                  )
                }}
              </Query>
              <button type="submit">{data ? "Save" : "Add"}</button>
            </fieldset>
          </form>
        )}
      </Mutation>
    )
  }
}

export default CharacterziationForm